@@ -72,7 +72,7 @@ class Net_DNS2
     /*
      * the current version of this library
      */
-    const VERSION = '1.4.3';
+    const VERSION = '1.4.4';
 
     /*
      * the default path to a resolv.conf file
@@ -920,7 +920,9 @@ class Net_DNS2
             //
             // grab the next DNS server
             //
-            $ns = each($this->nameservers);
+            $ns = current($this->nameservers);
+            next($this->nameservers);
+
             if ($ns === false) {
 
                 if (is_null($this->last_exception) == false) {
@@ -935,8 +937,6 @@ class Net_DNS2
                 }
             }
 
-            $ns = $ns[1];
-
             //
             // if the use TCP flag (force TCP) is set, or the packet is bigger than our 
             // max allowed UDP size- which is either 512, or if this is DNSSEC request,
